vortex\_creation package
====================================

.. automodule:: IMTreatment.vortex_creation
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.vortex_creation.vortex_creation

